import React from 'react';
import ReactDOM from 'react-dom';
import { scaleLinear, scaleOrdinal, max, hcl } from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useCities } from './useCities';
import { Marks } from './Marks';

const width = 960;
const height = 500;

const heightValue = (d) => d.population;
const maxHeight = 120;

const colorValue = d => d.country;

const App = () => {
  const worldAtlas = useWorldAtlas();
  const cities = useCities();

  if (!worldAtlas || !cities) {
    return <pre>Loading...</pre>;
  }

  const heightScale = scaleLinear()
    .domain([0, max(cities, heightValue)])
    .range([0, maxHeight]);

  const colorScale = scaleOrdinal().domain(cities.map(colorValue));
  const colorValues = colorScale.domain(); // removes duplicates
  colorScale.range(
    colorValues.map((value, i) => hcl((i / colorValues.length) * 360, 50, 70))
  );

  return (
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        cities={cities}
        heightScale={heightScale}
        heightValue={heightValue}
        colorScale={colorScale}
        colorValue={colorValue}
      />
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
